@@ -51,6 +51,7 @@
 
 #include "array-size.h"
 #include "cleanup.h"
+#include "isaligned.h"
 #include "minmax.h"
 #include "vector.h"
 
@@ -146,7 +147,6 @@ vddk_config (const char *key, const char *value)
     }
   }
   else if (strcmp (key, "config") == 0) {
-    /* See FILENAMES AND PATHS in nbdkit-plugin(3). */
     free (config);
     config = nbdkit_realpath (value);
     if (!config)
@@ -204,9 +204,9 @@ vddk_config (const char *key, const char *value)
     r64 = nbdkit_parse_size (value);
     if (r64 == -1)
       return -1;
-    if (r64 <= 0 || (r64 & 511) != 0) {
-      nbdkit_error ("create-size must be greater than zero and a multiple of "
-                    "512");
+    if (r64 <= 0 || !IS_ALIGNED (r64, VIXDISKLIB_SECTOR_SIZE)) {
+      nbdkit_error ("create-size must be greater than zero "
+                    "and a multiple of %d", VIXDISKLIB_SECTOR_SIZE);
       return -1;
     }
     create_size = r64;
@@ -241,7 +241,6 @@ vddk_config (const char *key, const char *value)
     filename = value;
   }
   else if (strcmp (key, "libdir") == 0) {
-    /* See FILENAMES AND PATHS in nbdkit-plugin(3). */
     free (libdir);
     libdir = nbdkit_realpath (value);
     if (!libdir)
@@ -483,6 +482,18 @@ static int
 vddk_get_ready (void)
 {
   load_library (true);
+
+#ifdef __linux__
+  /* Check for possible VDDK crash if /sys/class/scsi_disk is missing. */
+  if (library_version >= 8 &&
+      /* snapshot_moref && XXX unclear if necessary to trigger the bug */
+      !transport_modes &&
+      access ("/sys/class/scsi_disk", F_OK) == -1)
+    nbdkit_debug ("if nbdkit crashes when you open a connection, "
+                  "read this link for workarounds: "
+                  "https://issues.redhat.com/browse/RHEL-54377");
+#endif
+
   return 0;
 }
 
@@ -862,19 +873,19 @@ vddk_get_size (void *handle)
 {
   struct vddk_handle *h = handle;
   VixDiskLibInfo *info;
-  int64_t size;
   struct command info_cmd = { .type = INFO, .ptr = &info };
 
   if (send_command_and_wait (h, &info_cmd) == -1)
     return -1;
 
-  size = info->capacity * (int64_t)VIXDISKLIB_SECTOR_SIZE;
+  /* Compute the size and cache it into the handle. */
+  h->size = info->capacity * VIXDISKLIB_SECTOR_SIZE;
 
   VDDK_CALL_START (VixDiskLib_FreeInfo, "info")
     VixDiskLib_FreeInfo (info);
   VDDK_CALL_END (VixDiskLib_FreeInfo, 0);
 
-  return size;
+  return h->size;
 }
 
 /* Advertise most efficient block sizes. */
